@@ -11,6 +11,8 @@
 #' \code{"BOOTiid"} or \code{"BOOTcor"}.
 #' @param cleanOutliers Boolean variable to indicate whether the pre-whitenning of the influence functions TS should be done through a robust filter.
 #' @param fitting.method Distribution used in the standard errors computation. Should be one of "Exponential" (default) or "Gamma".
+#' @param freq.include Frequency domain inclusion criteria. Must be one of "All" (default), "Decimate" or "Truncate."
+#' @param freq.par Percentage of the frequency used if \code{"freq.include"} is "Decimate" or "Truncate. Default is 0.5.
 #' @param ... Additional parameters.
 #'
 #' @return A vector or a list depending on \code{se.method}.
@@ -36,6 +38,7 @@
 ESratio.SE = function(data, alpha = 0.1, rf = 0,
                       se.method=c("IFiid","IFcor","IFcorAdapt","IFcorPW","BOOTiid","BOOTcor")[c(1,3)],
                       cleanOutliers=FALSE, fitting.method=c("Exponential", "Gamma")[1],
+                      freq.include=c("All", "Decimate", "Truncate")[1], freq.par=0.5,
                       ...){
 
   data = checkData(data)
@@ -50,7 +53,10 @@ ESratio.SE = function(data, alpha = 0.1, rf = 0,
     for(mymethod in se.method){
       res[[mymethod]]=EstimatorSE(data, estimator.fun = "ESratio",
                                   se.method = mymethod, alpha=alpha,
-                                  rf = rf, ...)
+                                  rf = rf,
+                                  fitting.method=fitting.method,
+                                  freq.include=freq.include, freq.par=freq.par,
+                                  ...)
     }
     return(res)
   }
